import type { ComponentSize } from '../../..';
import type { ExtractPropTypes, PropType } from 'vue';
export declare const Props: {
    /**
     * @description binding value
     */
    readonly modelValue: NumberConstructor;
    /**
     * @description same as `id` in native input
     */
    readonly id: {
        readonly type: StringConstructor;
        readonly default: undefined;
    };
    /**
     * @description incremental step
     */
    readonly step: {
        readonly type: NumberConstructor;
        readonly default: 1;
    };
    /**
     * @description whether input value can only be multiple of step
     */
    readonly stepStrictly: BooleanConstructor;
    /**
     * @description the maximum allowed value
     */
    readonly max: {
        readonly type: NumberConstructor;
        readonly default: number;
    };
    /**
     * @description the minimum allowed value
     */
    readonly min: {
        readonly type: NumberConstructor;
        readonly default: number;
    };
    /**
     * @description same as `readonly` in native input
     */
    readonly readonly: BooleanConstructor;
    /**
     * @description whether the component is disabled
     */
    readonly disabled: BooleanConstructor;
    /**
     * @description size of the component
     */
    readonly size: {
        readonly type: PropType<ComponentSize>;
        readonly default: "default";
    };
    /**
     * @description whether to enable the control buttons
     */
    readonly controls: {
        readonly type: BooleanConstructor;
        readonly default: true;
    };
    /**
     * @description position of the control buttons
     */
    readonly controlsPosition: {
        readonly type: PropType<"" | "right">;
        readonly default: "";
    };
    /**
     * @description value should be set when input box is cleared
     */
    readonly valueOnClear: {
        readonly type: PropType<number | "max" | "min" | null>;
        readonly default: null;
    };
    /**
     * @description same as `name` in native input
     */
    readonly name: StringConstructor;
    /**
     * @description same as `label` in native input
     */
    readonly label: StringConstructor;
    /**
     * @description same as `placeholder` in native input
     */
    readonly placeholder: StringConstructor;
    /**
     * @description precision of input value
     */
    readonly precision: {
        readonly type: NumberConstructor;
    };
    /**
     * @description whether to trigger form validation
     */
    readonly validateEvent: {
        readonly type: BooleanConstructor;
        readonly default: true;
    };
};
export declare const Emits: {
    change: (cur: number | undefined, prev: number | undefined) => boolean;
    blur: (e: FocusEvent) => boolean;
    focus: (e: FocusEvent) => boolean;
    input: (val: number | null | undefined) => boolean;
    "update:modelValue": (val: number | undefined) => boolean;
};
export type InputNumberEmits = typeof Emits;
export type InputNumberProps = ExtractPropTypes<typeof Props>;
