import type { ExtractPropTypes, PropType, StyleValue } from 'vue';
import type { ComponentSize, IconSlotType } from '../../../types';
import type { InputType } from './interface';
export declare const Props: {
    /**
     * @description native input id
     */
    readonly id: {
        readonly type: StringConstructor;
        readonly default: undefined;
    };
    /**
     * @description input box size
     */
    readonly size: {
        readonly type: PropType<ComponentSize>;
        readonly default: "default";
    };
    /**
     * @description whether to disable
     */
    readonly disabled: BooleanConstructor;
    /**
     * @description binding value
     */
    readonly modelValue: {
        readonly type: PropType<string | number | null | undefined>;
        readonly default: "";
    };
    /**
     * @description type of input
     */
    readonly type: {
        readonly type: PropType<InputType>;
        readonly default: "text";
    };
    /**
     * @description control the resizability
     */
    readonly resize: {
        readonly type: PropType<"horizontal" | "vertical" | "none" | "both">;
    };
    /**
     * @description native input autocomplete
     */
    readonly autocomplete: {
        readonly type: StringConstructor;
        readonly default: "off";
    };
    /**
     * @description format content
     */
    readonly formatter: {
        readonly type: FunctionConstructor;
    };
    /**
     * @description parse content
     */
    readonly parser: {
        readonly type: PropType<Function>;
    };
    /**
     * @description placeholder
     */
    readonly placeholder: {
        readonly type: StringConstructor;
    };
    /**
     * @description native input form
     */
    readonly form: {
        readonly type: StringConstructor;
    };
    /**
     * @description native input readonly
     */
    readonly readonly: {
        readonly type: BooleanConstructor;
        readonly default: false;
    };
    /**
     * @description native input readonly
     */
    readonly clearable: {
        readonly type: BooleanConstructor;
        readonly default: false;
    };
    /**
     * @description toggleable password input
     */
    readonly showPassword: {
        readonly type: BooleanConstructor;
        readonly default: false;
    };
    /**
     * @description word count
     */
    readonly showWordLimit: {
        readonly type: BooleanConstructor;
        readonly default: false;
    };
    /**
     * @description suffix icon
     */
    readonly suffixIcon: {
        readonly type: PropType<IconSlotType>;
    };
    /**
     * @description prefix icon
     */
    readonly prefixIcon: {
        readonly type: PropType<IconSlotType>;
    };
    /**
     * @description container role, internal properties provided for use by the picker component
     */
    readonly containerRole: {
        readonly type: StringConstructor;
        readonly default: undefined;
    };
    /**
     * @description native input aria-label
     */
    readonly label: {
        readonly type: StringConstructor;
        readonly default: undefined;
    };
    /**
     * @description input tabindex
     */
    readonly tabindex: {
        readonly type: PropType<string | number>;
        readonly default: 0;
    };
    /**
     * @description whether to trigger form validation
     */
    readonly validateEvent: {
        readonly type: BooleanConstructor;
        readonly default: true;
    };
    /**
     * @description input or textarea element style
     */
    readonly inputStyle: {
        readonly type: PropType<StyleValue>;
        readonly default: () => {};
    };
    /**
     * @description native input autofocus
     */
    readonly autofocus: {
        readonly type: BooleanConstructor;
        readonly default: false;
    };
};
export declare const Emits: {
    "update:modelValue": (value: string) => boolean;
    input: (value: string) => boolean;
    change: (value: string) => boolean;
    focus: (evt: FocusEvent) => boolean;
    blur: (evt: FocusEvent) => boolean;
    clear: () => boolean;
    mouseleave: (evt: MouseEvent) => boolean;
    mouseenter: (evt: MouseEvent) => boolean;
    keydown: (evt: KeyboardEvent | Event) => boolean;
    compositionstart: (evt: CompositionEvent) => boolean;
    compositionupdate: (evt: CompositionEvent) => boolean;
    compositionend: (evt: CompositionEvent) => boolean;
};
export type InputEmits = typeof Emits;
export type InputProps = ExtractPropTypes<typeof Props>;
